function res=  coarsenpol(p,t)
//-----------------------------------------------------------------------  
// function res=  coarsenpol(p,t)
//
// it is a function which removes all the indices of the given polygon
// whose internal angles are more than %pi-t where t is the threshold.
//
// input     p            is a matrix with indices of polygon as elements 
//           t            threshold angle (with respect to which the
//                        coarsening is done)
//
// output:   res          is a coarsened polygon resulting from p       
//
//-----------------------------------------------------------------------  
//   $RCSfile: coarsenpol.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:15:07 $
//  Copyright: IIF-LMB $ Bhaskara Reddy. Poluru $
//
//-----------------------------------------------------------------------
//  $Log: coarsenpol.sci,v $
//  Revision 1.1  2003/10/16 12:15:07  haasdonk
//  intial version after release of presto-box 1.0, after renaming of old
//  repository patrec-lib
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------


  [out, in] = argn(0);
  if in ~=2,
    error('wrong number of input arguments.');
  end;
  
  //   finding the no. of indices of p
  n = size(p,2);
  q = fcycltrans(p,0,1);
  
  // finding the internal angles of the polygon p
  // formula: internal angle a= acos(-v1.v2/ |v1|.|v2|)  where 
  // v1 v2 are the line vectors of the sides of the polygon p
  v1 = q-p;
  v2 = fcycltrans(v1,0,1);
  
  // num = v1.v2, dot product of the two line vectors
  dp = v1.* v2; num= dp(1,:)+ dp(2,:) ;
  
  // l1 and l2 are | v1 |,  | v2 | symultaneously
  l1 = sqrt( v1(1,:) .* v1(1,:) + v1(2,:) .* v1(2,:) );
  l2 = sqrt( v2(1,:) .* v2(1,:) + v2(2,:) .* v2(2,:) );
  den = l1 .* l2;
  
  // 'a' is a 1*s matrix with all the internal angles of polygon p.
  a = acos(-num./den);
  s = size(a,2);
  
  // Selecting all indices of q with internal angle <= %pi-t into cq
  I = 1:s;
  i = [I(a<=(%pi-t))]; 
  cq = q(:,i);
  
  // we will get the coarsened polygon as follows
  
  if cq(:,$)==q(:,$),
    res = [cq(:,$),cq(:,1:$-1)];
  else 
    res = cq; 
  end;
    
endfunction









































