function res = fcycltrans(mat,m,n)
//-----------------------------------------------------------------------
// function res = fcycltrans(mat,m,n)
//
// fast implementation of cyclic translation for matrices.
//
// input:    mat          arbitrary typed matrix to be translated
//           m            Shift in y-Direction = first matrix-dimension!
//                        integer value.
//           n            Shift in x-Direction = second matrix-dimension!
//                        integer value.
//
// output:   res          cyclic translated matrix, e.g.
//                        cycltrans([1 2 3; 4 5 6; 7 8 9], 1,1)
//                        = [5 6 4; 8 9 7 ; 2 3 1]
//
//-----------------------------------------------------------------------  
//   $RCSfile: fcycltrans.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:15:07 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: fcycltrans.sci,v $
//  Revision 1.1  2003/10/16 12:15:07  haasdonk
//  intial version after release of presto-box 1.0, after renaming of old
//  repository patrec-lib
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
  [out,in] = argn(0);

  if in~=3, 
    error('wrong number of input arguments.');
  end;
  
  [ys, xs] = size(mat);
  
  m = modulo(modulo(m,ys)+ys,ys);
  n = modulo(modulo(n,xs)+xs,xs);
  
  doublemat = [mat, mat ; mat, mat];
  
  res = doublemat((1+m):(m+ys),(1+n):(n+xs));

endfunction;




