function res = monomvec(p,x)
//-----------------------------------------------------------------------  
// function px = monomvec(p,x)
//
// Calculation of power-substitution-vector, i.e. vector of monomials of x
//
// input:    p            desired polynomial degree.
//           x            input vector (x1, ..., xn) of arbitrary 
//                        length n (if matrix, each column is processed)
//
// output:   px           power substitution vector of x =
//                        (1, x1, ... , xn, x1^2, x1x2, ..., xn^2,
//                        ... xn^p)
//                        this is the lexicographical ordered set of 
//                        monomials of x of degree <= p
//                        if X is a matrix, result will be matrix
//                        with columnwise results.
//
//-----------------------------------------------------------------------  
//   $RCSfile: monomvec.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:15:07 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: monomvec.sci,v $
//  Revision 1.1  2003/10/16 12:15:07  haasdonk
//  intial version after release of presto-box 1.0, after renaming of old
//  repository patrec-lib
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
  n = size(x,1);
  
  if p>0;
    opx = monomvec(p-1,x);
    px = opx;
    lopx = size(opx,1);
    
    for i = 1:n
      sindex = 1+ lopx - binom_coeff(n+p-1-i, n-i);
      px = [px ; (opx(sindex:lopx,:) * diag(x(i,:)))];
    end  
    clear opx lopx x
  else 
    px = ones(1,size(x,2));
    clear x 
  end  
  
  res = px;
  
  if size(px,1)~= binom_coeff(n+p,p);
    error("wrong length of generated monomvec!");
  end
  
  clear p px n 
endfunction

  

