function s = detect_symmetry(Fc)
//-----------------------------------------------------------------------  
// function s = detect_symmetry(Fc)
//
// Detection of rotational symmetry degree of a polygon represented
// by its Fourier-coefficients.
//
// input:    Fc       complex valued vector of
//                    fourier-coefficients of some polygon
//
// output:   s        estimated maximum rotational symmetry degree
//
//-----------------------------------------------------------------------  
//   $RCSfile: detect_symmetry.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:16:46 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: 
//-----------------------------------------------------------------------
  
  Fc = abs(Fc(:));
  Fc(ceil(length(Fc)/2)) = 0;
  
  // Threshold
  [FcMax,iMax] = max(Fc);
  tresh = 0.1 * FcMax
  
  // Normalization of Fc
  N = [-floor(length(Fc)/2):floor(length(Fc)/2)]';
  Fc = Fc .* N.^2;
  
  // All possible symmetries
  S(1) = 0;
  
  for s = 2:length(Fc)-1      
    // Summation over relevant symmetries.
    no = 0;
    for n = 1:length(Fc)      
      if modulo(abs(n-iMax),s) ~= 0
	Fc_zero(n) = Fc(n);
      	no = no + 1;   
      else
	Fc_zero(n) = 0;
      end
    end
    
    // Decision function
    S(s) = sum(Fc_zero) / no;    
  end
  
  // decision
  N = (S < tresh)*1.0;
  
  // maximum symmtry
  [dummy,I] = sort(-N);
  s = I(length(I));
  
endfunction;



