function plotclassseq(learn_data, labels);
//-----------------------------------------------------------------------  
// function plotclassseq(learn_data, labels);
//
// Plot classifiers resulting from given learning data
//
// input:    learn_data   Matrix of columnwise learning vectors
//           labels       Vector with integer-label for each learning vector
//
//-----------------------------------------------------------------------  
//   $RCSfile: plotclassseq.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:16:46 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: plotclassseq.sci,v $
//  Revision 1.1  2003/10/16 12:16:46  haasdonk
//  initial version after release of presto-box 1.0, after rename of old
//  repository patrec-lib
//
//  Revision 1.3  2002/11/21 17:53:48  poluru
//  removed usage of global variable: DATA and used
//  "get_function_path" to find path of the library.
//
//  Revision 1.2  2002/09/10 16:43:22  poluru
//  added library stuff and errors check
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//  Revision 1.1  2002/05/13 15:49:42  haasdonk
//  initial version
//
//-----------------------------------------------------------------------

// learning data
  [out,in]=argn(0);
  
  if in ~=2, 
    if in~=0,
      error('wrong number of input arguments!');
    end;
    //global DATA
    //exec(DATA+'data.sci');

    path1 = get_function_path('plotclassseq');
    path2 = 'macros/visualization/plotclassseq.sci';
    dir_path = part(path1, 1:length(path1)-length(path2) );
    exec(dir_path+'data/data.sci', -1);
     
    learn_data = V ;
    labels = l;
  end;
  
  old= stacksize();
  if old(1)< 10^7;
    x_message(['current stacksize: '+string(old(1))+' is too less! ';...
	       'increase stacksize by the function: stacksize()']);
  else
    
    colm = [1, 0, 0; 0, 0, 1 ; 0, 1, 0];
    xset("colormap",colm);
    subplot(3,3,1);
   
    oldcol = xget('color');
    xselect();
    xname('plotclassseq');
    
    for j = 1:2
      i = find(labels==j);
      xset('color',j);    
      plot2d(learn_data(1,i),learn_data(2,i),style=-1,rect=[-3, -3, 3, 3]);
    end;
    xset('color',oldcol);
    xtitle('learning data');
    
    // Bayes_class
    subplot(3,3,2);
    xtitle('Bayes');
    [p1, m1, K1] = class_statistics(learn_data,labels,1);
    [p2, m2, K2] = class_statistics(learn_data,labels,2);
    visclass('classifier',bayes_class,p1,m1,K1,p2,m2,K2);
    
    
    // Nearest_Neighbour
    subplot(3,3,3);
    xtitle('nearest neighbour');    
    visclass('classifier',nneigh_class,learn_data, labels);
    
    // Pol_regress_1
    subplot(3,3,4);
    xtitle('polynomial deg. 1');
    visclass('classifier',polynom_class,1,learn_data, labels);
   
        
    // Pol_regress_2
    subplot(3,3,5);
    xtitle('polynomial deg. 2');
    visclass('classifier',polynom_class,2,learn_data, labels);
    
    
    // Pol_regress_5
    subplot(3,3,6);
    xtitle('polynomial deg. 5');
    visclass('classifier',polynom_class,5,learn_data, labels);
    
    
    // Pol_regress_8
    subplot(3,3,7);
    xtitle('polynomial deg. 8');
    visclass('classifier',polynom_class,8,learn_data, labels);

  end
  
endfunction;
